.loader {
  border: 16px solid #f3f3f3;
  border-radius: 50%;
  border-top: 16px solid #3498db;
  width: 60px;
  height: 60px;
  -webkit-animation: spin 2s linear infinite; /* Safari */
  animation: spin 2s linear infinite;
}

.stoppedloader {
  border: 16px solid #f3f3f3;
  border-radius: 90%;
  border-top: 16px solid #3498db;
  border-right: 16px solid #3498db;
  border-left: 16px solid #3498db;
  border-bottom: 16px solid #3498db;
  width: 60px;
  height: 60px;
}

/* Safari */
@-webkit-keyframes spin {
  0% { -webkit-transform: rotate(0deg); }
  100% { -webkit-transform: rotate(360deg); }
}

@keyframes spin {
  0% { transform: rotate(0deg); }
  100% { transform: rotate(360deg); }
}